﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Infragistics.Controls.Editors.Primitives;
using Infragistics.Windows;

namespace XamMultiColumnComboEditor
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public string DisplayMemberPath { get; set; }

        private ObservableCollection<Person> data = new ObservableCollection<Person>();

        public MainWindow()
        {
            InitializeComponent();
            DisplayMemberPath = "LastName";

            this.xmceEntities.SelectedItemsResetButtonVisibility = Visibility.Collapsed;
            this.xmceEntities.MultiSelectValueDelimiter = ',';
            this.xmceEntities.EmptyText = "Seleccione";
            this.xmceEntities.AllowMultipleSelection = true;
            this.xmceEntities.DisplayMemberPath = this.DisplayMemberPath;
            this.xmceEntities.CheckBoxVisibility = Visibility.Visible;

            data.Add(new Person() { Id = 1, LastName = "Doe", Age = 50 });
            data.Add(new Person() { Id = 2, LastName = "Doe", Age = 34.5555 });
            data.Add(new Person() { Id = 1, LastName = "Doe", Age = 56 });
            data.Add(new Person() { Id = 2, LastName = "Smith", Age = 23 });

            this.DataContext = data;
        }

        private void xmceEntities_Loaded(object sender, RoutedEventArgs e)
        {
            SpecializedTextBox textbox = Utilities.GetDescendantFromName(sender as DependencyObject, "TextBoxPresenter") as SpecializedTextBox;
            textbox.TextChanged += Textbox_TextChanged;
        }

        private void Textbox_TextChanged(object sender, TextChangedEventArgs e)
        {
            String text = (sender as SpecializedTextBox).Text;
            FilterCombo(text);
        }

        private void FilterCombo(string filterText)
        {
            if (String.IsNullOrEmpty(filterText))
            {
                //  Reset to full list.
                this.DataContext = data;
                return;
            }

            filterText = filterText.ToLower();

            this.DataContext = data.Where((x) =>
                {
                    //  Search all columns.
                    return x.Age.ToString().ToLower().Contains(filterText) ||
                        x.LastName.ToString().ToLower().Contains(filterText) ||
                        x.Id.ToString().ToLower().Contains(filterText);
                }).ToList();
        }
    }

    public class Person : INotifyPropertyChanged
    {
        private int id;

        public int Id
        {
            get { return id; }
            set
            {
                id = value;
                NotifyPropertyChanged("Id");
            }
        }

        private double age;

        public double Age
        {
            get { return age; }
            set { age = value; NotifyPropertyChanged("Age"); }
        }

        private String lastName;

        public String LastName
        {
            get { return lastName; }
            set { lastName = value; NotifyPropertyChanged("LastName"); }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }

        }

    }
}
